@@ -1,15 +1,18 @@
-__author__ = 'saeedamen' # Saeed Amen
+__author__ = "saeedamen"  # Saeed Amen
 
 #
 # Copyright 2016 Cuemacro
 #
-# Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the
-# License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0
+# Licensed under the Apache License, Version 2.0 (the "License"); you may not
+# use this file except in compliance with the License. You may obtain a copy of
+# the License at http://www.apache.org/licenses/LICENSE-2.0
 #
-# Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an
-# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on a "AS IS" BASIS, WITHOUT
+# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #
-# See the License for the specific language governing permissions and limitations under the License.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 #
 
 import abc
@@ -18,23 +21,26 @@ import copy
 from findatapy.market.marketdatarequest import MarketDataRequest
 from findatapy.util import ConfigManager, LoggerManager
 
+
 class DataVendor(object):
     """Abstract class for various data source loaders.
 
     """
+
     def __init__(self):
         self.config = ConfigManager().get_instance()
         # self.config = None
         return
 
     @abc.abstractmethod
-    def load_ticker(self, market_data_request):
+    def load_ticker(self, md_request):
         """Retrieves market data from external data source
 
         Parameters
         ----------
-        market_data_request : MarketDataRequest
-            contains all the various parameters detailing time series start and finish, tickers etc
+        md_request : MarketDataRequest
+            contains all the various parameters detailing time series start and
+            finish, tickers etc
 
         Returns
         -------
@@ -49,49 +55,52 @@ class DataVendor(object):
     def kill_session(self):
         return
 
-    def construct_vendor_market_data_request(self, market_data_request):
+    def construct_vendor_md_request(self, md_request):
         """Creates a MarketDataRequest with the vendor tickers
 
         Parameters
         ----------
-        market_data_request : MarketDataRequest
-            contains all the various parameters detailing time series start and finish, tickers etc
+        md_request : MarketDataRequest
+            contains all the various parameters detailing time series start and
+            finish, tickers etc
 
         Returns
         -------
         MarketDataRequest
         """
 
-        symbols_vendor = self.translate_to_vendor_ticker(market_data_request)
-        fields_vendor = self.translate_to_vendor_field(market_data_request)
+        symbols_vendor = self.translate_to_vendor_ticker(md_request)
+        fields_vendor = self.translate_to_vendor_field(md_request)
 
-        market_data_request_vendor = MarketDataRequest(md_request=market_data_request)
+        md_request_vendor = MarketDataRequest(
+            md_request=md_request)
 
-        market_data_request_vendor.tickers = symbols_vendor
-        market_data_request_vendor.fields = fields_vendor
+        md_request_vendor.tickers = symbols_vendor
+        md_request_vendor.fields = fields_vendor
 
-        market_data_request_vendor.old_tickers = market_data_request.tickers
+        md_request_vendor.old_tickers = md_request.tickers
 
-        return market_data_request_vendor
+        return md_request_vendor
 
-    def translate_to_vendor_field(self, market_data_request):
+    def translate_to_vendor_field(self, md_request):
         """Converts all the fields from findatapy fields to vendor fields
 
         Parameters
         ----------
-        market_data_request : MarketDataRequest
-            contains all the various parameters detailing time series start and finish, tickers etc
+        md_request : MarketDataRequest
+            contains all the various parameters detailing time series start 
+            and finish, tickers etc
 
         Returns
         -------
         List of Strings
         """
 
-        if market_data_request.vendor_fields is not None:
-            return market_data_request.vendor_fields
+        if md_request.vendor_fields is not None:
+            return md_request.vendor_fields
 
-        source = market_data_request.data_source
-        fields_list = market_data_request.fields
+        source = md_request.data_source
+        fields_list = md_request.fields
 
         if isinstance(fields_list, str):
             fields_list = [fields_list]
@@ -105,7 +114,9 @@ class DataVendor(object):
                 f = self.config.convert_library_to_vendor_field(source, field)
             except:
                 logger = LoggerManager().getLogger(__name__)
-                logger.warn("Couldn't find field conversion, did you type it correctly: " + field)
+                logger.warn(
+                    "Couldn't find field conversion, "
+                    "did you type it correctly: " + field)
 
                 return
 
@@ -114,27 +125,28 @@ class DataVendor(object):
         return fields_converted
 
     # Translate findatapy ticker to vendor ticker
-    def translate_to_vendor_ticker(self, market_data_request):
+    def translate_to_vendor_ticker(self, md_request):
         """Converts all the tickers from findatapy tickers to vendor tickers
 
         Parameters
         ----------
-        market_data_request : MarketDataRequest
-            contains all the various parameters detailing time series start and finish, tickers etc
+        md_request : MarketDataRequest
+            contains all the various parameters detailing time series start 
+            and finish, tickers etc
 
         Returns
         -------
         List of Strings
         """
 
-        if market_data_request.vendor_tickers is not None:
-            return market_data_request.vendor_tickers
+        if md_request.vendor_tickers is not None:
+            return md_request.vendor_tickers
 
-        category = market_data_request.category
-        source = market_data_request.data_source
-        freq = market_data_request.freq
-        cut = market_data_request.cut
-        tickers_list = market_data_request.tickers
+        category = md_request.category
+        source = md_request.data_source
+        freq = md_request.freq
+        cut = md_request.cut
+        tickers_list = md_request.tickers
 
         if isinstance(tickers_list, str):
             tickers_list = [tickers_list]
@@ -145,10 +157,14 @@ class DataVendor(object):
 
         for ticker in tickers_list:
             try:
-                t = self.config.convert_library_to_vendor_ticker(category, source, freq, cut, ticker)
+                t = self.config.convert_library_to_vendor_ticker(category,
+                                                                 source, freq,
+                                                                 cut, ticker)
             except:
                 logger = LoggerManager().getLogger(__name__)
-                logger.error("Couldn't find ticker conversion, did you type it correctly: " + ticker)
+                logger.error(
+                    "Couldn't find ticker conversion, did you type "
+                    "it correctly: " + ticker)
 
                 return
 
@@ -156,20 +172,22 @@ class DataVendor(object):
 
         return tickers_list_converted
 
-    def translate_from_vendor_field(self, vendor_fields_list, market_data_request):
+    def translate_from_vendor_field(self, vendor_fields_list,
+                                    md_request):
         """Converts all the fields from vendors fields to findatapy fields
 
         Parameters
         ----------
-        market_data_request : MarketDataRequest
-            contains all the various parameters detailing time series start and finish, tickers etc
+        md_request : MarketDataRequest
+            contains all the various parameters detailing time series start
+            and finish, tickers etc
 
         Returns
         -------
         List of Strings
         """
 
-        data_source = market_data_request.data_source
+        data_source = md_request.data_source
 
         if isinstance(vendor_fields_list, str):
             vendor_fields_list = [vendor_fields_list]
@@ -179,9 +197,11 @@ class DataVendor(object):
         fields_converted = []
 
         # If we haven't set the configuration files for automatic configuration
-        if market_data_request.vendor_fields is not None:
+        if md_request.vendor_fields is not None:
 
-            dictionary = dict(zip(self.get_lower_case_list(market_data_request.vendor_fields), market_data_request.fields))
+            dictionary = dict(zip(self.get_lower_case_list(
+                md_request.vendor_fields),
+                                  md_request.fields))
 
             for vendor_field in vendor_fields_list:
                 try:
@@ -189,14 +209,19 @@ class DataVendor(object):
                 except:
                     fields_converted.append(vendor_field)
 
-        # Otherwise used stored configuration files (every field needs to be defined!)
+        # Otherwise used stored configuration files (every field needs to be
+        # defined!)
         else:
             for vendor_field in vendor_fields_list:
                 try:
-                    v = self.config.convert_vendor_to_library_field(data_source, vendor_field)
+                    v = self.config.convert_vendor_to_library_field(
+                        data_source, vendor_field)
                 except:
                     logger = LoggerManager().getLogger(__name__)
-                    logger.error("Couldn't find field conversion, did you type it correctly: " + vendor_field + ", using 'close' as default.")
+                    logger.error(
+                        "Couldn't find field conversion, did you type it "
+                        "correctly: " + vendor_field +
+                        ", using 'close' as default.")
 
                     v = 'close'
 
@@ -211,7 +236,8 @@ class DataVendor(object):
         Parameters
         ----------
         md_request : MarketDataRequest
-            contains all the various parameters detailing time series start and finish, tickers etc
+            contains all the various parameters detailing time series start
+            and finish, tickers etc
 
         Returns
         -------
@@ -220,15 +246,16 @@ class DataVendor(object):
 
         if md_request.vendor_tickers is not None:
 
-            dictionary = dict(zip(self.get_lower_case_list(md_request.vendor_tickers), md_request.tickers))
+            dictionary = dict(
+                zip(self.get_lower_case_list(md_request.vendor_tickers),
+                    md_request.tickers))
 
             tickers_stuff = []
 
             for vendor_ticker in vendor_tickers_list:
                 tickers_stuff.append(dictionary[vendor_ticker.lower()])
 
-            return tickers_stuff # [item for sublist in tickers_stuff for item in sublist]
-
+            return tickers_stuff
 
         # tickers_list = md_request.tickers
 
@@ -246,7 +273,8 @@ class DataVendor(object):
                     md_request.freq, md_request.cut, vendor_ticker)
             except:
                 logger = LoggerManager().getLogger(__name__)
-                logger.error("Couldn't find ticker conversion, did you type it correctly: " + vendor_ticker)
+                logger.error("Couldn't find ticker conversion, "
+                             "did you type it correctly: " + vendor_ticker)
 
                 return
 
@@ -256,5 +284,3 @@ class DataVendor(object):
 
     def get_lower_case_list(self, lst):
         return [k.lower() for k in lst]
-
-
