@@ -1,15 +1,18 @@
-__author__ = 'saeedamen'
+__author__ = "saeedamen"  # Saeed Amen
 
 #
 # Copyright 2016 Cuemacro
 #
-# Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the
-# License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0
+# Licensed under the Apache License, Version 2.0 (the "License"); you may not
+# use this file except in compliance with the License. You may obtain a copy of
+# the License at http://www.apache.org/licenses/LICENSE-2.0
 #
-# Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an
-# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on a "AS IS" BASIS, WITHOUT
+# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #
-# See the License for the specific language governing permissions and limitations under the License.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 #
 
 from findatapy.util.dataconstants import DataConstants
@@ -25,7 +28,8 @@ data_constants = DataConstants()
 class MarketDataRequest(object):
     """Provides parameters for requesting market data.
 
-    Includes parameters to define the ticker we'd like to fetch, the start and finish dates for our request, as well as
+    Includes parameters to define the ticker we'd like to fetch, the start and
+    finish dates for our request, as well as
     the various fields we would like and also the frequency of the data.
 
     """
@@ -34,6 +38,7 @@ class MarketDataRequest(object):
     #
     # data_source eg. bbg, yahoo, quandl
     # start_date
+    
     # finish_date
     # tickers (can be list) eg. EURUSD
     # category (eg. fx, equities, fixed_income, cal_event, fundamental)
@@ -43,13 +48,17 @@ class MarketDataRequest(object):
     # fields (can be list)
     # vendor_tickers (optional)
     # vendor_fields (optional)
-    # cache_algo (eg. internet, disk, memory) - internet will forcibly download from the internet
+    # cache_algo (eg. internet, disk, memory) - internet will forcibly download 
+    # from the internet
     # abstract_curve (optional)
-    # environment (eg. prod, backtest) - old data is saved with prod, backtest will overwrite the last data point
-    # overrides (optional) - if you need to specify any data overrides (eg. for BBG)
+    # environment (eg. prod, backtest) - old data is saved with prod, backtest 
+    # will overwrite the last data point
+    # overrides (optional) - if you need to specify any data overrides 
+    # (eg. for BBG)
 
     def generate_key(self):
-        """Generate a key to describe this MarketDataRequest object, which can be used in a cache, as a hash-style key
+        """Generate a key to describe this MarketDataRequest object, which can 
+        be used in a cache, as a hash-style key
 
         Returns
         -------
@@ -59,44 +68,54 @@ class MarketDataRequest(object):
         """
         from findatapy.market.ioengine import SpeedCache
 
-        if self.freq == 'daily':
+        if self.freq == "daily":
             ticker = None
         else:
             ticker = self.tickers[0]
 
         self.__category_key = self.create_category_key(md_request=self, ticker=ticker)
 
-        return SpeedCache().generate_key(self, ['logger', '_MarketDataRequest__abstract_curve',
-                                                '_MarketDataRequest__cache_algo',
-                                                '_MarketDataRequest__overrides']) + "_df"
+        return SpeedCache().generate_key(self, 
+                                         ["logger", 
+                                          "_MarketDataRequest__abstract_curve",
+                                          "_MarketDataRequest__cache_algo",
+                                          "_MarketDataRequest__overrides",
+                                          "_MarketDataRequest__data_vendor_custom"]) \
+               + "_df"
 
     def __init__(self, data_source=None,
-                 start_date='year', finish_date=datetime.datetime.utcnow(),
+                 start_date="year", finish_date=datetime.datetime.utcnow(),
                  tickers=None, category=None, freq_mult=1, freq="daily",
                  gran_freq=None, cut="NYC",
-                 fields=['close'], cache_algo="internet_load_return",
+                 fields=["close"], cache_algo="internet_load_return",
                  vendor_tickers=None, vendor_fields=None,
-                 environment=data_constants.default_data_environment, trade_side='trade', expiry_date=None, resample=None, resample_how='last',
+                 environment=data_constants.default_data_environment, 
+                 trade_side="trade", expiry_date=None, 
+                 resample=None, resample_how="last",
 
                  split_request_chunks=0,
                  list_threads=1,
 
-                 fx_vol_part=data_constants.fx_vol_part, fx_vol_tenor=data_constants.fx_vol_tenor,
+                 fx_vol_part=data_constants.fx_vol_part, 
+                 fx_vol_tenor=data_constants.fx_vol_tenor,
                  fx_forwards_tenor=data_constants.fx_forwards_tenor,
                  base_depos_currencies=data_constants.base_depos_currencies,
                  base_depos_tenor=data_constants.base_depos_tenor,
 
                  data_engine = data_constants.default_data_engine,
 
-                 md_request=None, abstract_curve=None, quandl_api_key=data_constants.quandl_api_key,
-                 fred_api_key=data_constants.fred_api_key, alpha_vantage_api_key=data_constants.alpha_vantage_api_key,
+                 md_request=None, abstract_curve=None, 
+                 quandl_api_key=data_constants.quandl_api_key,
+                 fred_api_key=data_constants.fred_api_key, 
+                 alpha_vantage_api_key=data_constants.alpha_vantage_api_key,
                  eikon_api_key=data_constants.eikon_api_key,
                  push_to_cache=True,
                  overrides={},
-                 freeform_md_request={}
-                 ):
+                 freeform_md_request={},
+                 data_vendor_custom=data_constants.data_vendor_custom):
 
-        # Can deep copy MarketDataRequest (use a lock, so can be used with threading when downloading time series)
+        # Can deep copy MarketDataRequest (use a lock, so can be used with 
+        # threading when downloading time series)
         if md_request is not None:
             import threading
             lock = threading.Lock()
@@ -131,27 +150,33 @@ class MarketDataRequest(object):
                 self.resample = copy.deepcopy(md_request.resample)
                 self.resample_how = copy.deepcopy(md_request.resample_how)
 
-                self.split_request_chunks = copy.deepcopy(md_request.split_request_chunks)
+                self.split_request_chunks = \
+                    copy.deepcopy(md_request.split_request_chunks)
                 self.list_threads = copy.deepcopy(md_request.list_threads)
 
                 self.fx_vol_part = copy.deepcopy(md_request.fx_vol_part)
                 self.fx_vol_tenor = copy.deepcopy(md_request.fx_vol_tenor)
                 self.fx_forwards_tenor = copy.deepcopy(md_request.fx_forwards_tenor)
-                self.base_depos_currencies = copy.deepcopy(md_request.base_depos_currencies)
-                self.base_depos_tenor = copy.deepcopy(md_request.base_depos_tenor)
+                self.base_depos_currencies = \
+                    copy.deepcopy(md_request.base_depos_currencies)
+                self.base_depos_tenor = \
+                    copy.deepcopy(md_request.base_depos_tenor)
                 
                 self.data_engine = copy.deepcopy(md_request.data_engine)
 
                 self.abstract_curve = copy.deepcopy(md_request.abstract_curve)
                 self.quandl_api_key = copy.deepcopy(md_request.quandl_api_key)
                 self.fred_api_key = copy.deepcopy(md_request.fred_api_key)
-                self.alpha_vantage_api_key = copy.deepcopy(md_request.alpha_vantage_api_key)
+                self.alpha_vantage_api_key = \
+                    copy.deepcopy(md_request.alpha_vantage_api_key)
                 self.eikon_api_key = copy.deepcopy(md_request.eikon_api_key)
                 self.overrides = copy.deepcopy(md_request.overrides)
                 self.push_to_cache = copy.deepcopy(md_request.push_to_cache)
-                self.freeform_md_request = copy.deepcopy(md_request.freeform_md_request)
+                self.freeform_md_request = \
+                    copy.deepcopy(md_request.freeform_md_request)
 
                 self.tickers = copy.deepcopy(md_request.tickers)  # Need this after category in case have wildcard
+                self.data_vendor_custom = copy.deepcopy(md_request.data_vendor_custom)
         else:
             self.freq_mult = freq_mult
 
@@ -206,26 +231,28 @@ class MarketDataRequest(object):
                 self.tickers = vendor_tickers
 
             self.old_tickers = self.tickers
+            self.data_vendor_custom = data_vendor_custom
 
     def __str__(self):
         return "MarketDataRequest summary - " + self.generate_key()
 
     def create_category_key(self, md_request=None, ticker=None):
-        """Returns a category key for the associated MarketDataRequest, which can be used to create filenames (or
-        as part of a storage key in a cache)
+        """Returns a category key for the associated MarketDataRequest, which 
+        can be used to create filenames (or as part of a storage key in a cache)
 
         Parameters
         ----------
         md_request : MarketDataRequest
-            contains various properties describing time series to fetched, including ticker, start & finish date etc.
+            contains various properties describing time series to fetched, 
+            including ticker, start & finish date etc.
 
         Returns
         -------
         str
         """
 
-        category = 'default-cat'
-        cut = 'default-cut'
+        category = "default-cat"
+        cut = "default-cut"
 
         if md_request is None:
             md_request = self
@@ -236,16 +263,19 @@ class MarketDataRequest(object):
         source = md_request.data_source
         freq = md_request.freq
 
-        if ticker is None and (md_request.freq == 'intraday' or md_request.freq == 'tick'):
+        if ticker is None and (md_request.freq == "intraday" 
+                               or md_request.freq == "tick"):
             ticker = md_request.tickers[0]
 
         if md_request.cut is not None: cut = md_request.cut
 
         if (ticker is not None):
-            key = str(environment) + "." + str(category) + '.' + str(source) + '.' + str(freq) + '.' + str(cut) \
-                  + '.' + str(ticker)
+            key = str(environment) + "." + str(category) + "." + str(source) \
+                  + "." + str(freq) + "." + str(cut) \
+                  + "." + str(ticker)
         else:
-            key = str(environment) + "." + str(category) + '.' + str(source) + '.' + str(freq) + '.' + str(cut)
+            key = str(environment) + "." + str(category) + "." + str(source) \
+                  + "." + str(freq) + "." + str(cut)
 
         return key
 
@@ -256,11 +286,13 @@ class MarketDataRequest(object):
     @data_source.setter
     def data_source(self, data_source):
         try:
-            valid_data_source = ['ats', 'bloomberg', 'dukascopy', 'fred', 'gain', 'google', 'quandl', 'yahoo',
-                                 'boe', 'eikon']
+            valid_data_source = ["ats", "bloomberg", "dukascopy", "fred", 
+                                 "gain", "google", "quandl", "yahoo",
+                                 "boe", "eikon"]
 
             if not data_source in valid_data_source:
-                LoggerManager().getLogger(__name__).warning(data_source & " is not a defined data source.")
+                LoggerManager().getLogger(__name__).warning(
+                    data_source & " is not a defined data source.")
         except:
             pass
 
@@ -290,20 +322,22 @@ class MarketDataRequest(object):
 
         if tickers is not None:
             for tick in tickers:
-                if '*' in tick:
-                    start = ''
+                if "*" in tick:
+                    start = ""
 
                     if tick[-1] == "*" and tick[0] != "*":
                         start = "^"
 
-                    tick = start + "(" + tick.replace('*', '') + ")"
+                    tick = start + "(" + tick.replace("*", "") + ")"
 
                     if config is None:
                         from findatapy.util import ConfigManager
                         config = ConfigManager().get_instance()
 
-                    new_tickers.append(config.get_filtered_tickers_list_for_category(
-                        self.__category, self.__data_source, self.__freq, self.__cut, tick))
+                    new_tickers.append(
+                        config.get_filtered_tickers_list_for_category(
+                        self.__category, self.__data_source, self.__freq, 
+                            self.__cut, tick))
                 else:
                     new_tickers.append(tick)
 
@@ -328,7 +362,7 @@ class MarketDataRequest(object):
 
     @fields.setter
     def fields(self, fields):
-        valid_fields = ['open', 'high', 'low', 'close', 'volume', 'numEvents']
+        valid_fields = ["open", "high", "low", "close", "volume", "numEvents"]
 
         if not isinstance(fields, list):
             fields = [fields]
@@ -374,11 +408,13 @@ class MarketDataRequest(object):
     def freq(self, freq):
         freq = freq.lower()
 
-        valid_freq = ['tick', 'second', 'minute', 'intraday', 'hourly', 'daily', 'weekly', 'monthly', 'quarterly',
-                      'annually']
+        valid_freq = ["tick", "second", "minute", "intraday", "hourly", 
+                      "daily", "weekly", "monthly", "quarterly",
+                      "annually"]
 
         if not freq in valid_freq:
-            LoggerManager().getLogger(__name__).warning(freq + " is not a defined frequency")
+            LoggerManager().getLogger(__name__).warning(freq + 
+                                                        " is not a defined frequency")
 
         self.__freq = freq
 
@@ -391,18 +427,20 @@ class MarketDataRequest(object):
         try:
             gran_freq = gran_freq.lower()
 
-            valid_gran_freq = ['tick', 'second', 'minute', 'hourly', 'pseudodaily', 'daily', 'weekly', 'monthly',
-                               'quarterly', 'annually']
+            valid_gran_freq = ["tick", "second", "minute", "hourly", 
+                               "pseudodaily", "daily", "weekly", "monthly",
+                               "quarterly", "annually"]
 
             if not gran_freq in valid_gran_freq:
-                LoggerManager().getLogger(__name__).warning(gran_freq & " is not a defined frequency")
+                LoggerManager().getLogger(__name__).warning(
+                    gran_freq + " is not a defined frequency")
 
-            if gran_freq in ['minute', 'hourly']:
-                self.__freq = 'intraday'
-            elif gran_freq in ['tick', 'second']:
-                self.__freq = 'tick'
+            if gran_freq in ["minute", "hourly"]:
+                self.__freq = "intraday"
+            elif gran_freq in ["tick", "second"]:
+                self.__freq = "tick"
             else:
-                self.__freq = 'daily'
+                self.__freq = "daily"
         except:
             pass
 
@@ -477,62 +515,63 @@ class MarketDataRequest(object):
 
             date1 = datetime.datetime.utcnow()
 
-            if date == 'midnight':
-                date1 = datetime.datetime(date1.year, date1.month, date1.day, 0, 0, 0)
-            elif date == 'decade':
+            if date == "midnight":
+                date1 = datetime.datetime(date1.year, date1.month, 
+                                          date1.day, 0, 0, 0)
+            elif date == "decade":
                 date1 = date1 - timedelta(days=365 * 10)
-            elif date == 'year':
+            elif date == "year":
                 date1 = date1 - timedelta(days=365)
-            elif date == 'month':
+            elif date == "month":
                 date1 = date1 - timedelta(days=30)
-            elif date == 'week':
+            elif date == "week":
                 date1 = date1 - timedelta(days=7)
-            elif date == 'day':
+            elif date == "day":
                 date1 = date1 - timedelta(days=1)
-            elif date == 'hour':
+            elif date == "hour":
                 date1 = date1 - timedelta(hours=1)
             else:
-                # format expected 'Jun 1 2005 01:33', '%b %d %Y %H:%M'
+                # format expected "Jun 1 2005 01:33", "%b %d %Y %H:%M"
                 try:
-                    date1 = datetime.datetime.strptime(date, '%b %d %Y %H:%M')
+                    date1 = datetime.datetime.strptime(date, "%b %d %Y %H:%M")
                 except:
                     # self.logger.warning("Attempted to parse date")
                     i = 0
 
-                # format expected '1 Jun 2005 01:33', '%d %b %Y %H:%M'
+                # format expected "1 Jun 2005 01:33", "%d %b %Y %H:%M"
                 try:
-                    date1 = datetime.datetime.strptime(date, '%d %b %Y %H:%M')
+                    date1 = datetime.datetime.strptime(date, "%d %b %Y %H:%M")
                 except:
                     # self.logger.warning("Attempted to parse date")
                     i = 0
 
-                # format expected '1 June 2005 01:33', '%d %B %Y %H:%M'
+                # format expected "1 June 2005 01:33", "%d %B %Y %H:%M"
                 try:
-                    date1 = datetime.datetime.strptime(date, '%d %B %Y %H:%M')
+                    date1 = datetime.datetime.strptime(date, "%d %B %Y %H:%M")
                 except:
                     # self.logger.warning("Attempted to parse date")
                     i = 0
 
                 try:
-                    date1 = datetime.datetime.strptime(date, '%b %d %Y')
+                    date1 = datetime.datetime.strptime(date, "%b %d %Y")
                 except:
                     # self.logger.warning("Attempted to parse date")
                     i = 0
 
                 try:
-                    date1 = datetime.datetime.strptime(date, '%d %b %Y')
+                    date1 = datetime.datetime.strptime(date, "%d %b %Y")
                 except:
                     # self.logger.warning("Attempted to parse date")
                     i = 0
 
                 try:
-                    date1 = datetime.datetime.strptime(date, '%B %d %Y')
+                    date1 = datetime.datetime.strptime(date, "%B %d %Y")
                 except:
                     # self.logger.warning("Attempted to parse date")
                     i = 0
 
                 try:
-                    date1 = datetime.datetime.strptime(date, '%d %B %Y')
+                    date1 = datetime.datetime.strptime(date, "%d %B %Y")
                 except:
                     # self.logger.warning("Attempted to parse date")
                     i = 0
@@ -551,10 +590,12 @@ class MarketDataRequest(object):
     def cache_algo(self, cache_algo):
         cache_algo = cache_algo.lower()
 
-        valid_cache_algo = ['internet_load', 'internet_load_return', 'cache_algo', 'cache_algo_return']
+        valid_cache_algo = ["internet_load", "internet_load_return", 
+                            "cache_algo", "cache_algo_return"]
 
         if not cache_algo in valid_cache_algo:
-            LoggerManager().getLogger(__name__).warning(cache_algo + " is not a defined caching scheme")
+            LoggerManager().getLogger(__name__).warning(cache_algo + 
+                                                        " is not a defined caching scheme")
 
         self.__cache_algo = cache_algo
 
@@ -569,7 +610,8 @@ class MarketDataRequest(object):
         valid_environment = data_constants.possible_data_environment
 
         if not environment in valid_environment:
-            LoggerManager().getLogger(__name__).warning(environment + " is not a defined environment.")
+            LoggerManager().getLogger(__name__).warning(
+                environment + " is not a defined environment.")
 
         self.__environment = environment
 
@@ -581,10 +623,11 @@ class MarketDataRequest(object):
     def trade_side(self, trade_side):
         trade_side = trade_side.lower()
 
-        valid_trade_side = ['trade', 'bid', 'ask']
+        valid_trade_side = ["trade", "bid", "ask"]
 
         if not trade_side in valid_trade_side:
-            LoggerManager().getLogger(__name__).warning(trade_side + " is not a defined trade side.")
+            LoggerManager().getLogger(__name__).warning(
+                trade_side + " is not a defined trade side.")
 
         self.__trade_side = trade_side
 
